define(function(require, exports, module) {

    var Http = require('U/http');
    var Tips = require('U/tips');
    var favoriteList = new Vue({
        el: '#favoriteList',
        template: _g.getTemplate('favorite/index-list-V'),
        data: {
            list: []
        },
        created: function() {
            this.list = [];
        },
        methods: {
            onItemTap: function(index, event) {
                var item = this.list[index].topic;
                var action = $(event.target).attr('data-action');
                if (action == 'delete') {
                    postFavorite(item.id, index);
                    return;
                }

                if (item.type == 1) {
                    _g.openWin({
                        header: {
                            template: 'read/detail-header-V',
                            data: {
                                title: item.title,
                                subtitle: item.desc,
                            }
                        },
                        name: 'read-detail',
                        url: '../read/detail.html',
                        bounces: false,
                        pageParam: {
                            id: item.id,
                            tag: item.tag,
                        }
                    });
                } else if (item.type == 2) {
                    api.openWin({
                        name: 'book-index-win',
                        url: '../book/index.html',
                        slidBackEnabled: false,
                        pageParam: {
                            extra: item,
                        }
                    });
                }
            }
        }
    });

    function postFavorite(topicId, index) {
        Http.ajax({
            data: {
                topicId: topicId
            },
            url: '/api/favorite/del',
            success: function(ret) {
                if (ret.code == 200) {
                    favoriteList.list.splice(index, 1);
                    Tips.show({
                        title: '已取消收藏',
                    });
                }
            },
            error: function(err) {}
        });
    }

    function getData() {
        Http.ajax({
            data: {},
            url: '/api/favorite/list',
            success: function(ret) {
                if (ret.code == 200) {
                    setTimeout(function() {
                        favoriteList.list = _.map(ret.data, function(item) {
                            return {
                                id: item.id,
                                topic: item.topics,
                                topicId: item.topics.id,
                                image: item.topics.cover,
                                title: item.topics.title,
                                desc: item.topics.desc,
                                date: new Date(item.updDate).getTime()
                            }
                        });
                        initListTool();
                    }, 0);
                }
            },
            error: function(err) {}
        });
    }

    function initListTool() {
        var hammer = new Hammer($('.ui-list')[0], {});
        var $hammer_msg = null;
        var toolbar_width = 0;
        var hammer_allow = true;
        var hammer_end = false;
        hammer.on('panstart', function(ev) {
            $hammer_msg = $(ev.target).closest('.ui-list__item');
            toolbar_width = $hammer_msg.find('.ui-msgToolbar').width();
            hammer_end = false;
        });
        hammer.on('panmove', function(ev) {
            if (!hammer_allow) return;
            if ($hammer_msg.hasClass('is-active')) {
                if (ev.deltaX >= 0) {
                    $hammer_msg.find('.ui-list__itemBody').css({
                        'transition-duration': '0.2s',
                        '-webkit-transform': 'translate3d(0,0,0)'
                    });
                    hammer_allow = false;
                    setTimeout(function() {
                        $hammer_msg.removeClass('is-active');
                        hammer_end = true;
                    }, 200);
                }
            } else {
                if (ev.deltaX >= 20) {
                    ev.deltaX = 20;
                } else {
                    if (ev.deltaX < -toolbar_width - 20) {
                        ev.deltaX = -toolbar_width - 20;
                    }
                }
                $hammer_msg.find('.ui-list__itemBody').css({
                    '-webkit-transform': 'translate3d(' + ev.deltaX + 'px,0,0)',
                    'transition-duration': '0s'
                });
            }
        });
        hammer.on('panend', function(ev) {
            if (hammer_end) {
                hammer_allow = true;
                return;
            }
            if (ev.deltaX >= 0) {
                $hammer_msg.find('.ui-list__itemBody').css({
                    'transition-duration': '0.2s',
                    '-webkit-transform': 'translate3d(0,0,0)'
                });
                hammer_allow = false;
                setTimeout(function() {
                    $hammer_msg.removeClass('is-active');
                    hammer_allow = true;
                }, 200);

            } else if (ev.deltaX > -toolbar_width * 0.3 && ev.deltaX < 0) {
                $hammer_msg.find('.ui-list__itemBody').css({
                    'transition-duration': '0.2s',
                    '-webkit-transform': 'translate3d(0,0,0)'
                });
                hammer_allow = false;
                setTimeout(function() {
                    $hammer_msg.removeClass('is-active');
                    hammer_allow = true;
                }, 200);
            } else if (ev.deltaX <= -toolbar_width * 0.3) {
                $hammer_msg.find('.ui-list__itemBody').css({
                    'transition-duration': '0.2s',
                    '-webkit-transform': 'translate3d(' + (-toolbar_width) + 'px,0,0)'
                });
                hammer_allow = false;
                setTimeout(function() {
                    $hammer_msg.addClass('is-active');
                    hammer_allow = true;
                }, 200);
            }
        });
        hammer.on('pancancel panup', function(ev) {
            if (hammer_end) {
                hammer_allow = true;
                hammer_end = false;
                return;
            }
            if (ev.deltaX >= 0) {
                $hammer_msg.find('.ui-list__itemBody').css({
                    'transition-duration': '0.2s',
                    '-webkit-transform': 'translate3d(0,0,0)'
                });
                hammer_allow = false;
                setTimeout(function() {
                    $hammer_msg.removeClass('is-active');
                    hammer_allow = true;
                }, 200);

            } else if (ev.deltaX > -toolbar_width * 0.3 && ev.deltaX < 0) {
                $hammer_msg.find('.ui-list__itemBody').css({
                    'transition-duration': '0.2s',
                    '-webkit-transform': 'translate3d(0,0,0)'
                });
                hammer_allow = false;
                setTimeout(function() {
                    $hammer_msg.removeClass('is-active');
                    hammer_allow = true;
                }, 200);
            } else if (ev.deltaX <= -toolbar_width * 0.3) {
                $hammer_msg.find('.ui-list__itemBody').css({
                    'transition-duration': '0.2s',
                    '-webkit-transform': 'translate3d(' + (-toolbar_width) + 'px,0,0)'
                });
                hammer_allow = false;
                setTimeout(function() {
                    $hammer_msg.addClass('is-active');
                    hammer_allow = true;
                }, 200);
            }
        });
    }

    getData();

    module.exports = {};

});
