define(function(require, exports, module) {

    var Http = require('U/http');
    var wxPay = api.require('wxPay');
    var aliPay = api.require('aliPay');

    window.aliPayData = {};
    api.loadSecureValue({
        key: 'aliPay_partner'
    }, function(ret, err) {
        window.aliPayData.partner = ret.value;
    });

    api.loadSecureValue({
        key: 'aliPay_seller'
    }, function(ret, err) {
        window.aliPayData.seller = ret.value;
    });

    api.loadSecureValue({
        key: 'aliPay_rsaPriKey'
    }, function(ret, err) {
        window.aliPayData.rsaPriKey = ret.value;
    });

    api.loadSecureValue({
        key: 'aliPay_rsaPubKey'
    }, function(ret, err) {
        window.aliPayData.rsaPubKey = ret.value;
    });

    var vipUser = new Vue({
        el: '#vipUser',
        template: _g.getTemplate('me/vip-user-V'),
        data: {
            isVip: 1,
            title: '您还没有登录',
            subTitle: '立即购买为当前设备开通会员',
            paySelect: 0,
            payList: [{
                tag: 'is-alipay',
                title: '支付宝支付',
            }, {
                tag: 'is-weixin',
                title: '微信支付',
            }]
        },
        created: function() {
            var UserInfo = _g.getLS('UserInfo');
            if (UserInfo.isVip) {
                var date = new Date();
                date.setTime(UserInfo.endVipDate);
                this.isVip = UserInfo.isVip;
                this.title = UserInfo.userName;
                this.subTitle = date.Format('yyyy年MM月dd日');
            } else {
                this.isVip = UserInfo.isVip;
                this.title = UserInfo.userName;
                this.subTitle = '你还不是会员'
            }
        },
        methods: {
            onItemTap: function(index) {
                this.paySelect = index;
            },
            onBtnTap: function() {
                var type = 2;
                switch (Number(this.paySelect)) {
                    case 0:
                        type = 2;
                        break;
                    case 1:
                        type = 1;
                        break;
                    default:
                        type = 2;
                        break;
                }
                this.postOrder(type);
            },
            postOrder: function(type) {
                var self = this;
                Http.ajax({
                    data: {
                        type: type, // 支付类型, 1:微信 2:支付宝
                        total_fee: 30000, // 支付金额, 单位:分
                        body: '中国好父母入会充值', // 商品描述
                    },
                    url: '/api/pay/create',
                    success: function(ret) {
                        if (ret.code == 200) {
                            if (type == 1) {
                                self.wxPay(ret.data);
                            } else if (type == 2) {
                                self.aliPay(ret.data);
                            }
                        }
                    },
                    error: function(err) {}
                });
            },
            aliPay: function(data) {
                window.tradeNo = data.payData.tradeNO;
                var self = this;
                aliPay.config({
                    partner: aliPayData.partner,
                    seller: aliPayData.seller,
                    rsaPriKey: aliPayData.rsaPriKey,
                    rsaPubKey: aliPayData.rsaPubKey,
                    notifyURL: data.notifyURL
                }, function(ret, err) {
                    aliPay.pay(data.payData, function(ret, err) {
                        var code = Number(ret.code);
                        if (code == 9000) {
                            self.intervController();
                            _g.showProgress({
                                title: '等待支付结果...',
                                text: '先喝杯茶...',
                            });
                        } else {
                            if (code == 6001) {
                                // 取消支付
                            } else {
                                api.alert({
                                    title: '支付结果',
                                    msg: ret.code,
                                    buttons: ['确定']
                                });
                            }
                        }
                    });
                });
            },
            wxPay: function(data) {
                window.tradeNo = data.tradeNo;
                var self = this;
                wxPay.payOrder({
                    apiKey: 'wxe1dea687172c442a',
                    orderId: data.prepay_id,
                    mchId: data.mch_id,
                    nonceStr: data.nonce_str,
                    timeStamp: data.timestamp,
                    package: 'Sign=WXPay',
                    sign: data.sign
                }, function(ret, err) {
                    if (ret.status) {
                        self.intervController();
                        _g.showProgress({
                            title: '等待支付结果...',
                            text: '先喝杯茶...',
                        });
                    } else {
                        if (err.code == -2) {
                            // 取消支付
                        } else {
                            api.alert({
                                msg: err.code
                            });
                        }
                    }
                });
            },
            intervController: function() {
                var self = this;
                var interv = setInterval(function() {
                    self.checkStatus(function() {
                        clearInterval(interv);
                    })
                }, 1000);
            },
            checkStatus: function(callback) {
                var self = this;
                Http.ajax({
                    data: {
                        tradeNo: window.tradeNo,
                    },
                    lock: false,
                    url: '/api/pay/check',
                    success: function(ret) {
                        if (ret.code == 200) {
                            _g.hideProgress();
                            typeof callback == 'function' && callback();
                            api.alert({
                                title: '提示',
                                msg: '会员充值成功',
                            }, function(ret, err) {
                                // var UserInfo = _g.getLS('UserInfo');
                                // UserInfo.isVip = 1;
                                // _g.setLS('UserInfo', UserInfo);
                                api.sendEvent({
                                    name: 'me-info-getData',
                                });
                                api.closeWin();
                            });
                        } else {
                            console.log(ret.message)
                        }
                    },
                    error: function(err) {
                        console.log(err)
                    }
                })
            }
        }
    });

    var descList = new Vue({
        el: '#descList',
        template: _g.getTemplate('me/vip-list-V'),
        data: {
            list: [{
                // tag: 'is-key',
                icon: '',
                title: '万能钥匙',
                content: '可解锁往期VIP精华问题,全场听学,畅通无阻!'
            }, {
                // tag: 'is-hot',
                icon: '',
                title: '精选150个热门话题听学',
                content: '每周为您解答三个不同年龄阶段孩子的问题及您的困惑，全年以独特视角为您解读150个孩子成长的热门话题。'
            }, {
                // tag: 'is-move',
                icon: '',
                title: '移动课堂',
                content: '听话题解读音频,看话题解读视频,参与课后互动！'
            }, {
                // tag: 'is-offline',
                icon: '',
                title: '线下课程',
                content: '第一时间参加中国好父母各分会线下课程,现场交流分享智慧！'
            }]
        },
        created: function() {
            this.list = [];
        },
        methods: {
            onItemTap: function(index) {
                this.paySelect = index;
            }
        }
    });
    var getData = function() {
        Http.ajax({
            data: {
                type: 'vipInfo'
            },
            url: '/api/system/info',
            success: function(ret) {
                if (ret.code == 200) {
                    setTimeout(function() {
                        if (ret.data.length > 0) {
                            descList.list = _.map(ret.data, function(item) {
                                return {
                                    icon: item.icon,
                                    title: item.title,
                                    content: item.subtitle,
                                }
                            });
                        }
                    }, 0);
                }
            },
            error: function(err) {}
        });
    }
    getData();

    module.exports = {};

});
